require(['config'], function() {
    require([
        'jquery.bootstrap.fileUpload', //파일 업로드가 있는 페이지에서 로딩
        'kakao.postcode',
        'kakao.maps'
    ], function($) {
        pageObj.init();
    });
});

/********************************************************
 --------------------------------------------------------
 - Object 목록								            -
 --------------------------------------------------------
 * const gridColModel = {}	: 화면 Grid Object			*
 * let pageObj = {}			: 화면공통 Object			*
 * let listObj = {}			: 목록화면 Object			*
 * let viewObj = {}			: 상세화면 Object			*
 * let modifyObj = {}		: 수정화면 Object			*
 * let createObj = {}		: 신규화면 Object			*
 *******************************************************/

/*화면 변수*/
const OPER06010_GRID_ID = '#ITP_OPER06010_jqGrid';
const OPER06010_GRID_LIST = '#ITP_OPER06010_jqGrid_list';
const OPER06010_GRID_PAGER = '#ITP_OPER06010_jqGridPager';
const OPER06010_GRID_EMPTY = '#ITP_OPER06010_jqGridEmpty';

const OPER06010_VIEW_GRID_ID = '#ITP_OPER06010_VIEW_jqGrid';
const OPER06010_VIEW_GRID_LIST = '#ITP_OPER06010_VIEW_jqGrid_list';
const OPER06010_VIEW_GRID_PAGER = '#ITP_OPER06010_VIEW_jqGridPager';
const OPER06010_VIEW_GRID_EMPTY = '#ITP_OPER06010_VIEW_jqGridEmpty';

const OPER06010_DETAIL_GRID_ID = '#ITP_OPER06010_DETAIL_jqGrid';
const OPER06010_DETAIL_GRID_LIST = '#ITP_OPER06010_DETAIL_jqGrid_list';
const OPER06010_DETAIL_GRID_PAGER = '#ITP_OPER06010_DETAIL_jqGridPager';
const OPER06010_DETAIL_GRID_EMPTY = '#ITP_OPER06010_DETAIL_jqGridEmpty';

/*API URL*/
let API_DETAIL_GRID_LIST = '/api/brand/detail-grid-list';
let API_DETAIL_INFO = '/api/brand/info-brand';
let API_DETAIL_SAVE = '/api/brand/save-brand';

let ITP_FORM_OPER06010_DETAIL_IS_DUPLICATE = false;
let ITP_FORM_OPER06010_DETAIL_IS_WRITING = false;

/*화면 Grid Object*/
const gridColModel = {
    list: [
        {
            index: 'VIEW_CD', name: 'viewCd',
            label: ITP_MSG_LOCALE.label.viewCd,
            width: '10', fixed: false, align: 'center',
            sortable: false, hidden: true
        },
        {
            index: 'AFFL_SHOP_ID', name: 'afflShopId',
            label: ITP_MSG_LOCALE.label.afflShopId,
            width: '10', fixed: false, align: 'center',
            sortable: false, hidden: true
        },
        {
            index: 'AFFL_SHOP_NM', name: 'afflShopNm',
            label: ITP_MSG_LOCALE.label.afflShopNm, //가맹점
            width: '10', fixed: false, align: 'center',
            sortable: false, hidden: false
        },
        {
            index: 'BRAND_ID', name: 'brandId',
            label: ITP_MSG_LOCALE.label.brandId,
            width: '10', fixed: false, align: 'center',
            sortable: false, hidden: false
        },
        {
            index: 'BRAND_NM', name: 'brandNm',
            label: ITP_MSG_LOCALE.label.brandNm, //브랜드명
            width: '13', fixed: false, align: 'center',
            sortable: false, hidden: false
        },
        {
            index: 'ST_NM', name: 'stNm',
            label: ITP_MSG_LOCALE.label.stNm, //상태
            width: '10', fixed: false, align: 'center',
            sortable: false, hidden: false
        },
        {
            index: 'BRAND_TYPE_NM', name: 'brandTypeNm',
            label: ITP_MSG_LOCALE.label.brandTypeNm, //브랜드 타입
            width: '13', fixed: false, align: 'center',
            sortable: false, hidden: false
        },
        {
            index: 'REG_DT', name: 'regDt',
            label: ITP_MSG_LOCALE.label.regDt, //등록일
            width: '10', fixed: false, align: 'center',
            sortable: false, hidden: false
        }],
    view: [],
    detail: []
};

/*화면공통 Object*/
let pageObj = {
    init: function () {
        this.ui.init();
        this.event.init();
    },
    brandInfo: function() {
        return JSON.parse(sessionStorage.getItem('itp_manage_brand_info'));
    },
    ui: {
        init: function () {
            this.view();
            this.grid();
            this.ready();
        },
        view: function() {
            // 버튼 권한설정
            fn_proc_btn_auth('OPER06010');

            // 공통코드 표시
            $('select').each(function() {
                if($(this).data('select-code')) {
                    fn_make_select(CODE_LIST, $(this).data('select-code'), $(this).attr('id'));
                }
            });
        },
        grid: function() {
            itp_fn_jqgrid_resize(OPER06010_GRID_ID, OPER06010_GRID_LIST, 'lg');
            listObj.empty.init();
            itp_fn_fire_window_resize();
        },
        ready: function() {
            listObj.init();
        }
    },
    event: {
        init: function () {
            this.button();
        },
        button: function () {
            // 버튼 클릭 이벤트
            $('button').each(function() {
                var id = $(this).attr('id');
                $(this).on('click', function() {
                    switch (id) {
                        case 'ITP_BTN_OPER06010_SRH'				: listObj.button.search();		break;	// 조회 버튼 클릭
                        case 'ITP_BTN_OPER06010_NEWREG'				: listObj.button.create(); 		break;	// 신규등록 버튼
                        case 'ITP_BTN_OPER06010_MODIFY'				: modifyObj.button.modify();	break;	// 수정 버튼
                        case 'ITP_BTN_OPER06010_CANCELLIST'			: createObj.button.cancel(); 	break;	// 취소/목록 버튼
                        case 'ITP_BTN_OPER06010_DELETE'				: 								break;	// 삭제 버튼
                        case 'ITP_BTN_OPER06010_SAVE'				: createObj.button.save(); 		break;	// 저장 버튼
                        case 'ITP_FORM_OPER06010_DETAIL_DUP'		: createObj.button.duplicate();	break;	// 중복체크
                        case 'ITP_BTN_OPER06010_RESET_PW'			: createObj.button.resetPass();	break;	// 상세:비밀번호 초기화
                        case 'ITP_BTN_OPER06010_DETAIL_ADDROW'		: afflShopObj.button.addRow();	break;	// 상세:추가버튼
                        case 'ITP_BTN_OPER06010_DETAIL_DELROW'		: afflShopObj.button.delRow();	break;	// 상세:삭제버튼
                    }
                });
            });
        }
    },
    fileUpload: function() {
        //파일업로드(수정화면)
        var id = 'OPER06010';
        $('#ITP_' + id + '_DETAIL_UPLOAD').empty();
        const fileArgs = {
            'fileNo': $('#ITP_FORM_' + id + '_DETAIL_FILE_NO').val(),
            'viewCd': $('#ITP_FORM_' + id + '_DETAIL_VIEW_CD').val(),
            'showYn': $('#ITP_' + id + '_DETAIL_UPLOAD').attr('data-show-yn'),
            'fileId': '#ITP_FORM_' + id + '_DETAIL_FILE_NO' //파일번호를 서버에서 받아서 넣을 파일번호 인풋박스 아이디
        };
        itp_fn_set_file_upload('ITP_' + id + '_DETAIL_UPLOAD', 'notice', true, false, id, fileArgs);
    },
    switchScreen: function(mode) {
        if(mode == 'LIST') { // 목록
            $('#ITP_BTN_OPER06010_MODIFY').hide();
            $('#ITP_BTN_OPER06010_CANCELLIST').hide();
            $('#ITP_BTN_OPER06010_DELETE').hide();
            $('#ITP_BTN_OPER06010_SAVE').hide();
            fn_show_btn_auth('#ITP_BTN_OPER06010_SRH');
            fn_show_btn_auth('#ITP_BTN_OPER06010_NEWREG');

            $('#ITP_AJAX_OPER06010_LIST_CONTAINER').show();
            $('#ITP_AJAX_OPER06010_DETAIL_CONTAINER').hide();
            $('#ITP_AJAX_OPER06010_VIEW_CONTAINER').hide();
        } else if(mode == 'ADD') { // 등록
            ITP_FORM_OPER06010_DETAIL_IS_DUPLICATE = true;

            $('#ITP_BTN_OPER06010_SRH').hide();
            $('#ITP_BTN_OPER06010_MODIFY').hide();
            $('#ITP_BTN_OPER06010_NEWREG').hide();
            $('#ITP_BTN_OPER06010_DELETE').hide();
            $('#ITP_BTN_OPER06010_RESET_PW').hide();
            fn_show_btn_auth('#ITP_BTN_OPER06010_CANCELLIST');
            fn_show_btn_auth('#ITP_BTN_OPER06010_SAVE');

            $('#ITP_AJAX_OPER06010_LIST_CONTAINER').hide();
            $('#ITP_AJAX_OPER06010_DETAIL_CONTAINER').show();
            $('#ITP_AJAX_OPER06010_VIEW_CONTAINER').hide();
            $('#ITP_FORM_OPER06010_DETAIL_BRAND_CD').removeAttr('readonly');
            $('#ITP_FORM_OPER06010_DETAIL_DUP').removeAttr('disabled');

            $('#ITP_FORM_OPER06010_DETAIL_VIEW_CD').val('C');
            $('#ITP_FORM_OPER06010_DETAIL_BRAND_NM').val('');
            $('#ITP_FORM_OPER06010_DETAIL_BRAND_USE_CD').val('');
            $('#ITP_FORM_OPER06010_DETAIL_BRAND_CD').val('');
            $('#ITP_FORM_OPER06010_DETAIL_CATE_CD').val('');
            $('#ITP_FORM_OPER06010_DETAIL_TAKEOUT_YN').val('');
            $('#ITP_FORM_OPER06010_DETAIL_CIRCULATE_STORE_YN').val('');
            $('#ITP_FORM_OPER06010_DETAIL_STORE_MENU_REG_YN').val('');
            $('#ITP_FORM_OPER06010_DETAIL_SALES_USER_ID').val('');
            $('#ITP_FORM_OPER06010_DETAIL_SALES_USER_NM').val('');

        } else if(mode == 'MODIFY') { // 수정
            $('#ITP_BTN_OPER06010_SRH').hide();
            $('#ITP_BTN_OPER06010_MODIFY').hide();
            $('#ITP_BTN_OPER06010_NEWREG').hide();
            $('#ITP_BTN_OPER06010_DELETE').hide();
            fn_show_btn_auth('#ITP_BTN_OPER06010_CANCELLIST');
            fn_show_btn_auth('#ITP_BTN_OPER06010_SAVE');
            fn_show_btn_auth('#ITP_BTN_OPER06010_RESET_PW');

            $('#ITP_AJAX_OPER06010_LIST_CONTAINER').hide();
            $('#ITP_AJAX_OPER06010_DETAIL_CONTAINER').show();
            $('#ITP_AJAX_OPER06010_VIEW_CONTAINER').hide();
            $('#ITP_FORM_OPER06010_DETAIL_BRAND_CD').attr('readonly', true);
            $('#ITP_FORM_OPER06010_DETAIL_DUP').attr('disabled', true);
        } else if(mode == 'VIEW') { // 보기
            $('#ITP_BTN_OPER06010_SRH').hide();
            $('#ITP_BTN_OPER06010_NEWREG').hide();
            $('#ITP_BTN_OPER06010_DELETE').hide();
            $('#ITP_BTN_OPER06010_SAVE').hide();
            fn_show_btn_auth('#ITP_BTN_OPER06010_MODIFY');
            fn_show_btn_auth('#ITP_BTN_OPER06010_CANCELLIST');

            $('#ITP_AJAX_OPER06010_LIST_CONTAINER').hide();
            $('#ITP_AJAX_OPER06010_DETAIL_CONTAINER').hide();
            $('#ITP_AJAX_OPER06010_VIEW_CONTAINER').show();
        }
    }
};

/*목록화면 Object*/
let listObj = {
    init: function () {
        this.grid.init();
    },
    itp_OPER06010_param: {},
    itp_OPER06010_search: false,
    button: {
        search: function() {
            listObj.itp_OPER06010_search = true;
            let param = $('#ITP_FORM_OPER06010_SEARCH').serializeObject();
            param.gridSize = $.jgrid.defaults.rowNum;
            param.gridPage = $.jgrid.defaults.page;
            $(OPER06010_GRID_ID).setGridParam({'postData': JSON.stringify(param)}).trigger('reloadGrid');
        },
        create: function() {
            pageObj.switchScreen('ADD');
            itp_fn_form_clear_validate(null, '#ITP_FORM_OPER06010_DETAIL');
            // 권한정보 리스트 조회
            createObj.init();
        }
    },
    empty: {
        init: function() {
            var _this = this;
            this.push();
            $(OPER06010_GRID_EMPTY).on('click', function() {
                _this.back();
                listObj.itp_OPER06010_param.gridSize = $.jgrid.defaults.rowNum;
                $(OPER06010_GRID_ID).setGridParam({'postData': JSON.stringify(listObj.itp_OPER06010_param)}).trigger('reloadGrid');
            });
        },
        push: function() {
            let param = $('#ITP_FORM_OPER06010_SEARCH').serializeObject();
            listObj.itp_OPER06010_param = param;
        },
        back: function() {
            $('#ITP_FORM_OPER06010_SERVICE_BRAND_TYPE').val(listObj.itp_OPER06010_param.brandType);
            $('#ITP_FORM_OPER06010_SERVICE_ST_CD').val(listObj.itp_OPER06010_param.stCd);
            $('#ITP_FORM_OPER06010_SEARCH_BRAND_NM').val(listObj.itp_OPER06010_param.brandNm);
        }
    },
    grid: {
        init: function () {
            // 데이터 없을때
            listObj.empty.push();
            this.search();
        },
        colModel: gridColModel.list,
        search: function() {
            pageObj.switchScreen('LIST');
            this.unload();
            this.load();
        },
        load: function() {
            let param = $('#ITP_FORM_OPER01010_SEARCH').serializeObject();
            param.gridSize = $.jgrid.defaults.rowNum;

            var option = {
                gridId: OPER06010_GRID_ID,
                colModel: gridColModel.list,
                param: JSON.stringify(param),
                url: DOMAIN + API_DETAIL_GRID_LIST,
                pager: OPER06010_GRID_PAGER,
                onCellSelect: function(rowId, cellIdx, cellValue) {
                    var cm = $(this).jqGrid('getGridParam', 'colModel');
                    var colNm = cm[cellIdx].name;
                    if (colNm === 'brandId') {
                        const brandIdVal = $(this).jqGrid('getCell', rowId, 'brandId');
                        const key = {brandId: brandIdVal, viewCd: 'R'};
                        var param = $.param(key);
                        viewObj.init(param);
                    }
                },
                loadComplete: function(data) {
                    //console.log(JSON.stringify(data));
                    itp_fn_grid_load_complete(data, OPER06010_GRID_ID, true, 'number', 'OPER06010', listObj.itp_OPER06010_search, listObj.empty, true, data.gridRecords, true);
                    var ids = $(OPER06010_GRID_ID).getDataIDs();
                    $.each(ids, function(idx, rowId) {
                        $(OPER06010_GRID_ID).jqGrid('setCell', rowId, 'brandId', '', ITP_GRID_COL_STYLE.link);
                    });
                },
                onPaging: function(action) {
                    itp_fn_grid_paging(OPER06010_GRID_ID, action, param);
                }
            };
            itp_fn_grid_make_remote(option);
        },
        clearData : function() {
            $(OPER06010_GRID_ID).jqGrid('clearGridData', true);
            $(OPER06010_GRID_LIST).find('.ui-jqgrid-bdiv').css('min-height', '100px');
            $(OPER06010_GRID_EMPTY).html(ITP_MSG_LOCALE.message.grid.noData);
            $(OPER06010_GRID_EMPTY).show();
        },
        unload : function() {
            $.jgrid.gridUnload(OPER06010_GRID_ID);
        }
    }
};

/*상세화면 Object*/
let viewObj = {
    init: function (param) {
        this.load(param);
    },
    load: function(param) {
        fn_ajax_call(API_DETAIL_INFO, param, this.callback, 'GET');
    },
    callback: function (result) {
        // console.log(result);
        pageObj.switchScreen('VIEW');
        $('#ITP_FORM_OPER06010_VIEW #ITP_FORM_OPER06010_VIEW_AFFL_SHOP_ID').val(result.afflShopId);
        $('#ITP_FORM_OPER06010_VIEW #ITP_FORM_OPER06010_VIEW_BRAND_ID').val(result.brandId);
        $('#ITP_FORM_OPER06010_VIEW .fnBrandUnitUnqNo').text(result.brandId);
        $('#ITP_FORM_OPER06010_VIEW .fnStCd').text(result.stCd);
        $('#ITP_FORM_OPER06010_VIEW .fnBrandNm').text(result.brandNm);
        $('#ITP_FORM_OPER06010_VIEW .fnBrandType').text(result.brandType);
        $('#ITP_FORM_OPER06010_VIEW .fnTelNo').text(result.telNo);
        $('#ITP_FORM_OPER06010_VIEW .fnFaxNo').text(result.faxNo);
        $('#ITP_FORM_OPER06010_VIEW .fnEmalAddr').text(result.email);
        $('#ITP_FORM_OPER06010_VIEW .fnDpstBnkCd').text(result.bnkCd);
        $('#ITP_FORM_OPER06010_VIEW .fnRcvAcctNo').text(result.acctNo);
        $('#ITP_FORM_OPER06010_VIEW .fnOwacNm').text(result.owacNm);
        $('#ITP_FORM_OPER06010_VIEW .fnZipNo').text(result.zipNo);
        $('#ITP_FORM_OPER06010_VIEW .fnLoadAddr').text(result.addr1);
        $('#ITP_FORM_OPER06010_VIEW .fnDtlAddr').text(result.addr2);
        $('#ITP_FORM_OPER06010_VIEW .fnRegId').text(result.sysRegId);
        $('#ITP_FORM_OPER06010_VIEW .fnRegDt').text(result.sysRegDttm);
        $('#ITP_FORM_OPER06010_VIEW .fnChgId').text(result.sysChgId);
        $('#ITP_FORM_OPER06010_VIEW .fnChgDt').text(result.sysChgDttm);
        // $('#ITP_FORM_OPER06010_VIEW .fnBrandLogo').text(result.lastLoginDt);
    }
};

/*수정화면 Object*/
let modifyObj = {
    button: {
        modify: function () {
            itp_fn_form_clear_validate(null, '#ITP_FORM_OPER06010_DETAIL');
            const brandIdVal = $('#ITP_FORM_OPER06010_VIEW_BRAND_ID').val();
            const key = {brandId: brandIdVal, viewCd: 'R'};
            var param = $.param(key);
            modifyObj.load(param);
        }
    },
    load: function(param) {
        fn_ajax_call(API_DETAIL_INFO, param, this.callback, 'GET');
    },
    callback: function (result) {
        console.log(result);
        pageObj.switchScreen('MODIFY');
        $('#ITP_FORM_OPER06010_DETAIL #ITP_FORM_OPER06010_DETAIL_VIEW_CD').val('U');

        $('#ITP_FORM_OPER06010_DETAIL .fnBrandId').text(result.brandId);
        $('#ITP_FORM_OPER06010_DETAIL #ITP_FORM_OPER06010_DETAIL_BRANDP_ID').val(result.brandId);
        $('#ITP_FORM_OPER06010_DETAIL #ITP_FORM_OPER06010_DETAIL_ST_CD').val(result.stCd);
        $('#ITP_FORM_OPER06010_DETAIL #ITP_FORM_OPER06010_DETAIL_BRAND_NM').val(result.brandNm);
        $('#ITP_FORM_OPER06010_DETAIL #ITP_FORM_OPER06010_DETAIL_BRAND_TYPE').val(result.brandType);
        $('#ITP_FORM_OPER06010_DETAIL #ITP_FORM_OPER06010_DETAIL_BSNS_REG_NO').val(result.bsnsRegNo);
        $('#ITP_FORM_OPER06010_DETAIL #ITP_FORM_OPER06010_DETAIL_CORP_REG_NO').val(result.corpRegNo);
        $('#ITP_FORM_OPER06010_DETAIL #ITP_FORM_OPER06010_DETAIL_TEL_NO').val(result.telNo);
        $('#ITP_FORM_OPER06010_DETAIL #ITP_FORM_OPER06010_DETAIL_FAX_NO').val(result.faxNo);
        $('#ITP_FORM_OPER06010_DETAIL #ITP_FORM_OPER06010_DETAIL_EMAL_ADDR').val(result.emalAddr);
        $('#ITP_FORM_OPER06010_DETAIL #ITP_FORM_OPER06010_DETAIL_DPST_BNK_CD').val(result.dpstBnkCd);
        $('#ITP_FORM_OPER06010_DETAIL #ITP_FORM_OPER06010_DETAIL_RCV_ACCT_NO').val(result.acctNo);
        $('#ITP_FORM_OPER06010_DETAIL #ITP_FORM_STNFO01010_DETAIL_OWAC_NM').val(result.owacNm);
        $('#ITP_FORM_OPER06010_DETAIL #ITP_FORM_OPER06010_DETAIL_ZIPNO').val(result.zipNo);
        $('#ITP_FORM_OPER06010_DETAIL #ITP_FORM_OPER06010_DETAIL_LOAD_ADDR').val(result.addr1);
        $('#ITP_FORM_OPER06010_DETAIL #ITP_FORM_OPER06010_DETAIL_DTL_ADDR').val(result.addr2);

        $('#ITP_FORM_OPER06010_DETAIL .fnAddDt').text(result.sysRegDttm);
        $('#ITP_FORM_OPER06010_DETAIL .fnChgDt').text(result.sysChgDttm);

        let locate = result.addr1 + ' ' + result.addr2;
        kakaoMap.init('ITP_FORM_OPER06010_DETAIL_MAP', locate);

    }
};

/*신규화면 Object*/
let createObj = {
    init: function () {
        pageObj.fileUpload();
        $('#ITP_FORM_OPER06010_DETAIL_BRAND_ID').val(pageObj.brandInfo().brandId);
        kakaoMap.init('ITP_FORM_OPER06010_DETAIL_MAP', '');
    },
    button: {
        address: function() {
            new daum.Postcode({
                oncomplete: function(data) {
                    // 전체주소 리턴
                    document.getElementById('ITP_FORM_OPER03010_DETAIL_ZIPNO').value = data.zonecode;
                    document.getElementById('ITP_FORM_OPER03010_DETAIL_ADRES').value = data.roadAddress;
                    document.getElementById('ITP_FORM_OPER03010_DETAIL_LOTS_ADDRESS').value = !!data.autoJibunAddress ? data.autoJibunAddress : data.jibunAddress;
                    document.getElementById('ITP_FORM_OPER03010_DETAIL_STREET_ADDRESS').value = data.roadAddress;
                    document.getElementById('ITP_FORM_OPER03010_DETAIL_HJ_DONG').value = !!data.hname ? data.hname : data.bname;
                    document.getElementById('ITP_FORM_OPER03010_DETAIL_BJ_DONG').value = data.bname;

                    kakaoMap.init('ITP_FORM_OPER03010_DETAIL_MAP', data.roadAddress);
                    document.getElementById('ITP_FORM_OPER03010_DETAIL_ADRES_DTL').focus();
                }
            }).open();
        },
        save: function() {
            const formId = '#ITP_FORM_OPER03010_DETAIL';
            itp_fn_form_clear_validate(null, formId);
            var vali_brandCd = itp_fn_form_validate(formId, formId + '_BRAND_ID', ['empty'], undefined);
            var vali_brandUseCd = itp_fn_form_validate(formId, formId + '_BRAND_USE_CD', ['empty'], undefined);
            var vali_brandNm = itp_fn_form_validate(formId, formId + '_BRAND_NM', ['empty'], undefined);

            if (vali_brandCd && vali_brandUseCd && vali_brandNm) {
                if (ITP_FORM_OPER06010_DETAIL_IS_DUPLICATE) {
                    itp_fn_modal_duplicate(ITP_MSG_LOCALE.label.brandId, formId + '_BRAND_ID');
                } else {
                    let param = $(formId).serializeObject();

                    var searhFn = function() {
                        ITP_FORM_OPER06010_DETAIL_IS_WRITING = false;
                        listObj.grid.search();
                    };
                    fn_ajax_call(API_DETAIL_SAVE, JSON.stringify(param), searhFn, 'POST');
                }
            }
        },
        cancel: function () {
            listObj.grid.search();
        }
    }
};

let kakaoMap = {
    init: function(id, locate) {
        this.load(id, locate);
    },
    geocoder: null,
    schDetailAddrFromCoords: function(coords, callback) {
        // 좌표로 법정동 상세 주소 정보를 요청합니다
        if(this.geocoder) {
            this.geocoder.coord2Address(coords.getLng(), coords.getLat(), callback);
        }
    },
    getMap: function(id) {
        var mapContainer = document.getElementById(id), // 지도를 표시할 div
            mapOption = {
                center: new kakao.maps.LatLng(37.56684, 126.97865), // 지도의 중심좌표
                level: 3, // 지도의 확대 레벨
                mapTypeId : kakao.maps.MapTypeId.ROADMAP // 지도종류
            };

        // 지도를 생성한다
        var map = new kakao.maps.Map(mapContainer, mapOption);

        // 마우스 휠과 모바일 터치를 이용한 지도 확대, 축소를 막는다
        map.setZoomable(false);

        // 지도에 확대 축소 컨트롤을 생성한다
        //var zoomControl = new kakao.maps.ZoomControl();

        // 지도의 우측에 확대 축소 컨트롤을 추가한다
        //map.addControl(zoomControl, kakao.maps.ControlPosition.RIGHT);

        return map;
    },
    marker: function(map, coords) {
        // 지도에 마커를 생성하고 표시한다
        marker = new kakao.maps.Marker({
            position: coords, // 마커의 좌표
            map: map // 마커를 표시할 지도 객체
        });
    },
    load: function(id, locate) {
        var _this = this;
        kakao.maps.load(function() {
            var map = _this.getMap(id);
            // 주소-좌표 변환 객체를 생성합니다
            _this.geocoder = new kakao.maps.services.Geocoder();
            if( !locate || locate.length == 0 ) {
                // 지도에 마커를 생성하고 표시한다
                _this.marker(map, new kakao.maps.LatLng(37.56684, 126.97865));
            } else {
                // 주소로 좌표를 검색합니다
                _this.geocoder.addressSearch(locate, function(result, status) {
                    // 정상적으로 검색이 완료됐으면
                    if (status === kakao.maps.services.Status.OK) {

                        var coords = new kakao.maps.LatLng(result[0].y, result[0].x);
                        if(id === 'ITP_FORM_OPER06010_DETAIL_MAP') {
                            document.getElementById('ITP_FORM_OPER06010_DETAIL_LAT').value = result[0].y;
                            document.getElementById('ITP_FORM_OPER06010_DETAIL_LNG').value = result[0].x;
                        }

                        // 결과값으로 받은 위치를 마커로 표시합니다
                        _this.marker(map, coords);

                        // 지도의 중심을 결과값으로 받은 위치로 이동시킵니다
                        map.setCenter(coords);
                    } else {
                        _this.marker(map, new kakao.maps.LatLng(37.56684, 126.97865));
                    }
                });
            }

            if(id === 'ITP_FORM_OPER06010_DETAIL_MAP') {
                _this.listener.drag(map);
            }
        });
    },
    listener: {
        drag: function(map) {
            var _this = this;
            // 지도 드래깅 이벤트를 등록한다 (드래그 시작 : dragstart, 드래그 종료 : dragend)
            kakao.maps.event.addListener(map, 'drag', function () {
                kakaoMap.schDetailAddrFromCoords(map.getCenter(), function(result, status) {
                    if (status === kakao.maps.services.Status.OK) {

                        document.getElementById('ITP_FORM_OPER06010_DETAIL_LOTS_ADDRESS').value = result[0].address.address_name ;
                        document.getElementById('ITP_FORM_OPER06010_DETAIL_ADRES').value = !!result[0].road_address ? result[0].road_address.address_name : result[0].address.address_name ;
                        document.getElementById('ITP_FORM_OPER06010_DETAIL_STREET_ADDRESS').value = !!result[0].road_address ? result[0].road_address.address_name : $('#ITP_FORM_OPER06010_DETAIL_STREET_ADDRESS').val();
                        document.getElementById('ITP_FORM_OPER06010_DETAIL_ZIPNO').value = !!result[0].road_address ? result[0].road_address.zone_no : $('#ITP_FORM_OPER06010_DETAIL_CMPY_ZIPNO').val() ;
                        document.getElementById('ITP_FORM_OPER06010_DETAIL_LAT').value = map.getCenter().getLat();
                        document.getElementById('ITP_FORM_OPER06010_DETAIL_LNG').value = map.getCenter().getLng();

                        // 마커를 클릭한 위치에 표시합니다
                        marker.setPosition(map.getCenter());
                        marker.setMap(map);
                    }
                });
                /* 	var message = '지도를 드래그 하고 있습니다. 지도의 중심 좌표는 ' + map.getCenter().toString() +' 입니다.';
                console.log(message); */
            });
        }
    }
};
